@@ -190,7 +190,7 @@ sub output_conf_general {
         $output .= Bigtop::Backend::Conf::General::config(
             {
                 var   => 'root',
-                value => 'html',
+                value => 'html/templates',
             }
         );
     }
@@ -236,6 +236,8 @@ sub output_gantry_locations_general {
     my $data         = shift;
     my $location     = $data->{ location };
 
+    return if $self->is_base_controller;
+
     my %child_loc    = @{ $child_output };
 
     if ( keys %child_loc != 1 ) {
