@@ -174,7 +174,7 @@ like this:
         # engine          MP13;
         engine          MP20;
         template_engine TT;
-        Init            Std             { no_gen 1; }
+        Init            Std             {}
         SQL             Postgres        {}
         Control         Gantry          {}
         Model           GantryDBIxClass {}
@@ -736,14 +736,24 @@ What input type the user will use to enter/edit values of this field.
 
     html_form_type textarea;
 
-Choose from text, textarea, or select.  If you choose select, and your
-field does not have a refers_to statement, you need to include the
-html_form_options statement.
+Choose from text, textarea, select, or display.  If you choose select, and
+your field does not have a refers_to statement, you need to include the
+html_form_options statement.  If you choose display, the data in the
+underlying database row will be displayed (if it is available), but not
+in an input element, so users cannot change it.
 
 =item html_form_rows and html_form_cols
 
 For fields of type textarea, controls height and width of the text area's box.
 
+=item html_form_foreign
+
+(registered by Bigtop::Backend::Control::Gantry)
+
+Applies to fields of html_form_type 'display.'  Indicates that the field
+is a foreign key which use the foreign_display of the foreign row instead
+of its id.
+
 =item non_essential
 
 (registered by Bigtop::Backend::Model)
@@ -924,9 +934,21 @@ To decline imports:
 
     uses Gantry::Utils::AutoCRUD => `qw()`;
 
+=item gen_uses
+
+(registered by Bigtop::Backend::Control)
+
+Just like uses, except that the modules are only used in the GEN module.
+
+=item stub_uses
+
+(registered by Bigtop::Backend::Control)
+
+Just like uses, except that the modules are only used in the stub module.
+
 =back
 
-There are three controller types:
+There are four controller types:
 
 =over 4
 
@@ -963,6 +985,28 @@ is exactly equivalent to
     controller MySpecialOne {
     }
 
+=item base_controller
+
+You may have one base_controller in your bigtop file.  Use it if you
+want to include non-default things in the apps's base module.  To replace
+the default behavior, you need at least this:
+
+    controller is base_controller {
+        method do_main is base_links {
+            title `Your Choice`;
+        }
+        method site_links is links {}
+    }
+
+Once you do that, you should put any app level location or uses statement
+inside the block.  You may not use rel_location inside a base controller,
+but most other statements will work as they would for any other controller.
+Further, there is no restriction on methods types in either base
+controllers or regular controllers.
+
+It is unwise to include multiple base controllers, no error will be
+reported, but strange things will surely happen.
+
 =back
 
 There are two blocks for controllers:
@@ -1015,6 +1059,19 @@ statements are:
 
 =over 4
 
+=item rows
+
+The number of rows to include on each main listing page.
+
+=item paged_conf
+
+The name of the conf variable which holds the number of rows to include
+on each main listing page.  Dispite the name and the previous sentence,
+this is actually the name of the accessor which returns the number of
+rows and need not be part of conf.  It must be the name of a method
+on the Gantry site object.  So, the easiest way to set it up is to
+define a conf variable of the same name.
+
 =item cols
 
 A comma separated list of the fields from the controlled table which should
@@ -1157,6 +1214,29 @@ details about what the backend makes in this case.
 
 =back
 
+=item base_links
+
+This makes a default do_main style method for the base module of the app.
+It only understands to special keywords (besides extra_args):
+
+=over 4
+
+=item title
+
+The browser page title.
+
+=item template
+
+Defaults to main.tt.  The name of a template to use for rendering the
+nav links.
+
+=back
+
+=item links
+
+This makes a standard site_links style method.  It does not understand
+any keywords other than extra_args.
+
 =back
 
 =head1 Bigtop Backends
@@ -1289,6 +1369,20 @@ By default the use statement will have a full import list.
 
 =item Init Std
 
+For historical reasons, you may say:
+
+    Init Std { MANIFEST no_gen; }
+
+But this is now exactly equivalent to the more usual:
+
+    Init Std { no_gen 1; }
+
+Since all other files generated by Init Std are now (as of version 0.19)
+stubs, which are not subject to overwriting.
+
+It is not illegal to list the other files in no_gen statements, but it
+has no effect.
+
 =item Model GantryDBIxClass
 
 If you use this backend, you should set the dbix statement in the Control
