@@ -257,7 +257,7 @@ With the --new option to bigtop the config section looks like this:
      engine          CGI;
      template_engine TT;
 
-     Init      Std             { no_gen 1; }
+     Init      Std             {}
      SQL       SQLite          {}
      SQL       Postgres        {}
      SQL       MySQL           {}
@@ -267,14 +267,6 @@ With the --new option to bigtop the config section looks like this:
      SiteLook  GantryDefault   {}
  }
 
-Note that billing.example does not have C<no_gen> for Init Std.  After
-you build it with
-
-    bigtop --create billing.bigtop
-
-you should set C<no_gen> as above so the Changes, README, etc. are not
-rewritten.
-
 First there are two statements.  They request the engine and template
 engine which will service the app.  This one will run under CGI (for
 the time being) and will rely on Template Toolkit for output formatting.
@@ -284,19 +276,23 @@ add a backend (HttpdConf Gantry), regenerate, and be ready to go.
 After the statements is a list of the backends which built things for us.
 Take this line for example:
 
-        Init            Std             { no_gen 1; }
+        Init            Std             {}
 
 This specifies that the Bigtop::Backend::Init::Std module should be loaded
-whenever bigtop runs.  But, the no_gen statement tells it not to do anything.
-Since Init builds Changes, README, etc. from useless stubs, you don't want
-it to make them again, overwriting what you typed into them.  Every backend
-can be turned off in this way.
+whenever bigtop runs.  We could load the backend, but ask it not to do
+anything by changing this statement to:
 
-Init Std is still listed for two reasons.  First, it shows people which
-module did the Init building.  Second, it allows Bigtop::Backend::Init::Std to
-register any keywords it understands.  This keeps you from having parse
-errors for statements that Init Std would have understood, but the other
-modules don't use.  All of this is more important for the other backends.
+        Init            Std             { no_gen 1; }
+
+Initially (as it were) Init Std builds lots of things, like Changes, README,
+and Build.PL.  After that, all it ever does is update MANIFST.  By setting
+no_gen, you ask it not to do that; presumably because you have a more
+manual scheme in mind for MANIFEST maintenance.  Every backend can be turned
+off in this way.  Turning off a backend, instead of removing it, allows
+it to register its keywords.  If your source file uses keywords specific
+to a backend, failing to include that backend will lead to parse errors.
+Turning off the backend lets people know you used it in the past and lets
+the Parser know you want it to recognize the backend's keywords.
 
 In addition to Init, bigtop put seven other backends to work for us.
 Three of these build schema files for databases, making it easier to
@@ -552,7 +548,8 @@ entered.
 =item html_form_type
 
 the input type for this field when it appears in an HTML form.
-Current Gantry templates only understand select, text, and textarea.
+Current Gantry templates only understand select, text, textarea, and
+display.
 
 =item html_form_optional
 
@@ -862,6 +859,19 @@ the controller's stub and GEN modules:
 [ except that both use statements will list all
 of the default exports explicitly. ]
 
+Remember that stubs are never regenerated (unless you delete or rename
+them), so adding a use statement to your controller will not work for the
+stub once it is built.
+
+=item gen_uses
+
+Just like uses, except that the modules are only used in the GEN module.
+
+=item stub_uses
+
+Just like uses, except that the modules are only used in the stub module.
+This still won't alter an existing stub module.
+
 =item text_description
 
 This is the phrase which will appear in questions like, 'Should I really
@@ -902,11 +912,27 @@ recognizes four types: main_listing, AutoCRUD_form, CRUD_form, and stub.
             row_options      Edit, Delete;
         }
 
-A main listing is an HTML table listing all the rows in the underlying
+A main listing is an HTML table listing of rows in the underlying
 table sorted by the columns that appear in the foreign_display.  This
 is not suitable for complex controllers.  But, for all the tables
 in this app, it is good enough (at least until there are too many rows
-in the table).
+in the table).  To control the number of rows on each page of listing
+output add this:
+
+            rows 20;
+
+Alternatively, you could add:
+
+            paged_conf listing_rows
+
+where listing_rows is the name of an accessor on your site object (usually
+that accessor is generated by defining a conf variable of the same name
+in the app level config block:
+
+    config {
+        #...
+        listing_rows 15;
+    }
 
 The simple statements in a main_listing method block are:
 
